@@ -16,7 +16,7 @@ from lxml import html
 user_agent = {"User-Agent": "git.io/wanda"}
 content_json = "application/json"
 folder = f'{str(Path.home())}/wanda'
-version = '0.57.1'
+version = '0.57.2'
 
 
 def parser():
@@ -440,8 +440,9 @@ def handle_source(home, lock, source, term):
         set_wp(artstation_any(term), home, lock)
     elif contains(source, False, ["re", "reddit"]):
         if "@" in term:
-            set_wp(reddit(term.split("@")[1], term.split("@")[0]))
-        set_wp(reddit(search=term), home, lock)
+            set_wp(reddit(term.split("@")[1], term.split("@")[0]), home, lock)
+        else:
+            set_wp(reddit(search=term), home, lock)
     else:
         print("Unknown source")
 
